features

Function features 

pub fn features(bb: &Bitboard, player: u8) -> [f64; 6]
Compute the 6-dimensional handcrafted feature vector for bb.

Features are from player’s perspective (see FEATURE_NAMES), but player need not be the side to move: it is simply the perspective the caller wants scored. bb should be non-terminal.